#! /bin/bash
#
# Evaltools installation script
# =============================
#
#    ./install.sh [OPTION] ...
#
# OPTIONS
#    -c install dependencies using anaconda instead of pip
#    -e install evaltools in editable mode (changes in evaltools' sources
#       are automatically taken into account without the need of
#       re-installation)
#    -u install evaltools in local mode (to be used when you do not have
#       root privilege)

while getopts ecu option; do
    case "${option}"
        in
        e) editable=true;;
        c) conda_install=true;;
        u) user_install=true;;
    esac
done

# go to the script directory
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null && pwd )"
cd $DIR

# dependences installation
if [ $conda_install ]; then
    conda install --file requirements.txt
    conda install --file optional-requirements.txt
else
    for line in $(cat requirements.txt); do
        if [ $user_install ]; then
            pip install --user --upgrade $line
        else
            pip install --upgrade $line
        fi
    done
    for line in $(cat optional-requirements.txt); do
        if [ $user_install ]; then
            pip install --user --upgrade $line
            pip uninstall shapely
            pip install --user shapely --no-binary shapely
        else
            pip install --upgrade $line
            pip uninstall shapely
            pip install shapely --no-binary shapely
        fi
    done
fi

# evaltools installation
if [ $editable ]; then
    if [ $user_install ]; then
        pip install --user -e .
    else
        pip install -e .
    fi
else
    if [ $user_install ]; then
        pip install --user .
    else
        pip install .
    fi
fi
